@@ -14,7 +14,7 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
 #ifndef msfilter_h
@@ -61,7 +61,7 @@ typedef int (*MSFilterMethodFunc)(struct _MSFilter *f, void *arg);
 typedef void (*MSFilterNotifyFunc)(void *userdata, struct _MSFilter *f, unsigned int id, void *arg);
 
 struct _MSFilterMethod{
-	int id;
+	unsigned int id;
 	MSFilterMethodFunc method;
 };
 
@@ -242,54 +242,51 @@ extern "C"{
  * supported.
  *
  * @param desc    a filter description.
+ * @deprecated use ms_factory_register_filter().
  */
-MS2_PUBLIC void ms_filter_register(MSFilterDesc *desc);
+MS2_PUBLIC MS2_DEPRECATED void ms_filter_register(MSFilterDesc *desc);
 
 /**
  * Retrieve capture filter that supports encoding to codec name.
  *
  * @param mime    A string indicating the codec.
  *
- * Returns: a MSFilterDesc if successfull, NULL otherwise.
+ * @return a MSFilterDesc if successfull, NULL otherwise.
+ * @deprecated use ms_factory_get_encoding_capturer().
  */
-MS2_PUBLIC MSFilterDesc * ms_filter_get_encoding_capturer(const char *mime);
+MS2_PUBLIC MS2_DEPRECATED MSFilterDesc * ms_filter_get_encoding_capturer(const char *mime);
 
 /**
  * Retrieve render filter that supports decoding to codec name.
  *
  * @param mime    A string indicating the codec.
  *
- * Returns: a MSFilterDesc if successfull, NULL otherwise.
+ * @returns a MSFilterDesc if successfull, NULL otherwise.
+ * @deprecated use ms_factory_get_decoding_renderer()
  */
-MS2_PUBLIC MSFilterDesc * ms_filter_get_decoding_renderer(const char *mime);
+MS2_PUBLIC MS2_DEPRECATED MSFilterDesc * ms_filter_get_decoding_renderer(const char *mime);
 
 /**
  * Retrieve encoders according to codec name.
  *
- * Internal supported codecs:
- *    PCMU, PCMA, speex, gsm
- * Existing Public plugins:
- *    iLBC
  *
  * @param mime    A string indicating the codec.
  *
- * Returns: a MSFilterDesc if successfull, NULL otherwise.
+ * @return a MSFilterDesc if successfull, NULL otherwise.
+ * @deprecated use ms_factory_get_encoder().
  */
-MS2_PUBLIC MSFilterDesc * ms_filter_get_encoder(const char *mime);
+MS2_PUBLIC MS2_DEPRECATED MSFilterDesc * ms_filter_get_encoder(const char *mime);
 
 /**
  * Retrieve decoders according to codec name.
  *
- * Internal supported codecs:
- *    PCMU, PCMA, speex, gsm
- * Existing Public plugins:
- *    iLBC
  *
  * @param mime    A string indicating the codec.
  *
- * Returns: a MSFilterDesc if successfull, NULL otherwise.
+ * @return a MSFilterDesc if successfull, NULL otherwise.
+ * @deprecated use ms_factory_get_decoder().
  */
-MS2_PUBLIC MSFilterDesc * ms_filter_get_decoder(const char *mime);
+MS2_PUBLIC MS2_DEPRECATED MSFilterDesc * ms_filter_get_decoder(const char *mime);
 
 /**
  * Lookup a mediastreamer2 filter using its name.
@@ -298,76 +295,70 @@ MS2_PUBLIC MSFilterDesc * ms_filter_get_decoder(const char *mime);
  * This function can be useful to query the presence of a filter loaded as a plugin, for example.
  *
  * @param filter_name The filter name.
+ * @return a MSFilterDesc or NULL if no match.
+ * @deprecated use ms_factory_lookup_filter_by_name().
 **/
-MS2_PUBLIC MSFilterDesc *ms_filter_lookup_by_name(const char *filter_name);
+MS2_PUBLIC MS2_DEPRECATED MSFilterDesc *ms_filter_lookup_by_name(const char *filter_name);
 
 /**
  * Returns a list of filter descriptions implementing a given interface.
  * The list itself must be freed by the caller of this function, but not the MSFilterDesc pointed by the list elements.
  * @param id a filter interface id
  * @return a newly allocated MSList of #MSFilterDesc.
+ * @deprecated use ms_factory_lookup_filter_by_interface().
 **/
-MS2_PUBLIC MSList *ms_filter_lookup_by_interface(MSFilterInterfaceId id);
+MS2_PUBLIC MS2_DEPRECATED MSList *ms_filter_lookup_by_interface(MSFilterInterfaceId id);
 
 /**
  * Create encoder filter according to codec name.
- *
- * Internal supported codecs:
- *    PCMU, PCMA, speex, gsm
- * Existing Public plugins:
- *    iLBC
- *
+ 
  * @param mime    A string indicating the codec.
  *
- * Returns: a MSFilter if successfull, NULL otherwise.
+ * @return a MSFilter if successfull, NULL otherwise.
+ * @deprecated use ms_factory_create_encoder().
  */
-MS2_PUBLIC MSFilter * ms_filter_create_encoder(const char *mime);
+MS2_PUBLIC MS2_DEPRECATED MSFilter * ms_filter_create_encoder(const char *mime);
 
 /**
  * Create decoder filter according to codec name.
  *
- * Internal supported codecs:
- *    PCMU, PCMA, speex, gsm
- * Existing Public plugins:
- *    iLBC
  *
  * @param mime    A string indicating the codec.
  *
- * Returns: a MSFilter if successfull, NULL otherwise.
+ * @return a MSFilter if successfull, NULL otherwise.
+ * @deprecated use ms_factory_create_decoder().
  */
-MS2_PUBLIC MSFilter * ms_filter_create_decoder(const char *mime);
+MS2_PUBLIC MS2_DEPRECATED MSFilter * ms_filter_create_decoder(const char *mime);
 
 /**
- * Check if a encode or decode filter exists for a codec name.
- *
- * Internal supported codecs:
- *    PCMU, PCMA, speex, gsm
- * Existing Public plugins:
- *    iLBC
+ * Check if both an encoder and a decoder filter exists for a codec name.
  *
  * @param mime    A string indicating the codec.
  *
- * Returns: TRUE if successfull, FALSE otherwise.
+ * @return TRUE if successfull, FALSE otherwise.
+ * @deprecated use ms_factory_codec_supported().
  */
-MS2_PUBLIC bool_t ms_filter_codec_supported(const char *mime);
+MS2_PUBLIC MS2_DEPRECATED bool_t ms_filter_codec_supported(const char *mime);
 
 /**
  * Create decoder filter according to a filter's MSFilterId.
  *
  * @param id     A MSFilterId identifier for the filter.
  *
- * Returns: a MSFilter if successfull, NULL otherwise.
+ * @returns a MSFilter if successfull, NULL otherwise.
+ * @deprecated use ms_factory_create_filter().
  */
-MS2_PUBLIC MSFilter *ms_filter_new(MSFilterId id);
+MS2_PUBLIC MS2_DEPRECATED MSFilter *ms_filter_new(MSFilterId id);
 
 /**
  * Create decoder filter according to a filter's name.
  *
  * @param name   A name for the filter.
  *
- * Returns: a MSFilter if successfull, NULL otherwise.
+ * @return a MSFilter if successfull, NULL otherwise.
+ * @deprecated use ms_factory_create_filter_from_name().
  */
-MS2_PUBLIC MSFilter *ms_filter_new_from_name(const char *name);
+MS2_PUBLIC MS2_DEPRECATED MSFilter *ms_filter_new_from_name(const char *name);
 
 /**
  * Create decoder filter according to a filter's description.
@@ -377,9 +368,10 @@ MS2_PUBLIC MSFilter *ms_filter_new_from_name(const char *name);
  *
  * @param desc   A MSFilterDesc for the filter.
  *
- * Returns: a MSFilter if successfull, NULL otherwise.
+ * @return a MSFilter if successfull, NULL otherwise.
+ * @deprecated use ms_factory_create_filter_from_desc()
  */
-MS2_PUBLIC MSFilter *ms_filter_new_from_desc(MSFilterDesc *desc);
+MS2_PUBLIC MS2_DEPRECATED MSFilter *ms_filter_new_from_desc(MSFilterDesc *desc);
 
 /**
  * Link one OUTPUT pin from a filter to an INPUT pin of another filter.
@@ -587,26 +579,26 @@ MS2_PUBLIC int ms_connection_helper_unlink(MSConnectionHelper *h, MSFilter *f, i
  * \brief Enable processing time measurements statistics for filters.
  *
 **/
-MS2_PUBLIC void ms_filter_enable_statistics(bool_t enabled);
+MS2_PUBLIC MS2_DEPRECATED void ms_filter_enable_statistics(bool_t enabled);
 
 
 /**
  * \brief Reset processing time statistics for filters.
  *
 **/
-MS2_PUBLIC void ms_filter_reset_statistics(void);
+MS2_PUBLIC MS2_DEPRECATED void ms_filter_reset_statistics(void);
 
 /**
  * \brief Retrieves statistics for running filters.
  * Returns a list of MSFilterStats
 **/
-MS2_PUBLIC const MSList * ms_filter_get_statistics(void);
+MS2_PUBLIC MS2_DEPRECATED const MSList * ms_filter_get_statistics(void);
 
 /**
  * \brief Logs runtime statistics for running filters.
  *
 **/
-MS2_PUBLIC void ms_filter_log_statistics(void);
+MS2_PUBLIC MS2_DEPRECATED void ms_filter_log_statistics(void);
 
 
 
@@ -686,7 +678,7 @@ the method index (_cnt_) and the argument size */
 #define MS_FILTER_GET_LATENCY	MS_FILTER_BASE_METHOD(11,int)
 
 typedef struct _MSPinFormat{
-	int pin;
+	uint16_t pin;
 	const MSFmtDescriptor *fmt;
 }MSPinFormat;
 
